## ----knitr-options, echo=FALSE, message=FALSE, warning=FALSE------------------
library(knitr)
opts_chunk$set(echo = TRUE)

## ----init---------------------------------------------------------------------
library("SAMEclustering")
data("data_SAME")

## ----setup for Zheng dataset--------------------------------------------------
dim(data_SAME$Zheng.expr)

data_SAME$Zheng.expr[1:5, 1:5]

## ----individual clustering for Zheng dataset, results='hide', fig.show="hide", warning=FALSE----
cluster.result <- individual_clustering(inputTags = data_SAME$Zheng.expr, datatype = "count", percent_dropout = 10, SC3 = TRUE, CIDR = TRUE, nPC.cidr = NULL, Seurat = TRUE, nPC.seurat = NULL, resolution = 0.9, tSNE = TRUE, dimensions = 2, perplexity = 30, SIMLR = TRUE, diverse = TRUE, SEED = 123)

## ---- message=FALSE-----------------------------------------------------------
cluster.result[1:4, 1:10]

## ----cluster ensemble for Zheng dataset, results='hide'-----------------------
cluster.ensemble <- SAMEclustering(Y = t(cluster.result), rep = 3, SEED = 123)

## ----ensemble results for Zheng dataset, message=FALSE------------------------
cluster.ensemble

## ----ARI calculation for Zheng dataset----------------------------------------
library(cidr)

# Cell labels of ground truth
head(data_SAME$Zheng.celltype)

# Calculating ARI for cluster ensemble
adjustedRandIndex(cluster.ensemble$AICcluster, data_SAME$Zheng.celltype)

## ----setup for Biase dataset--------------------------------------------------
dim(data_SAME$Biase.expr.expr)

data_SAME$Biase.expr[1:5, 1:5]

## ----individual clustering for Biase dataset, results='hide', fig.show="hide", warning=FALSE----
cluster.result <- individual_clustering(inputTags = data_SAME$Biase.expr, datatype = "FPKM",  percent_dropout = 10, SC3 = TRUE, CIDR = TRUE, nPC.cidr = NULL, Seurat = TRUE, nPC.seurat = NULL, seurat_min_cell = 200, resolution_min = 1.2, tSNE = TRUE, dimensions = 2, tsne_min_cells = 200, tsne_min_perplexity = 10, SIMLR = TRUE, diverse = TRUE, SEED = 123)

## ----cluster ensemble for Biase dataset, results='hide', message=FALSE--------
cluster.ensemble <- SAMEclustering(Y = t(cluster.result), rep = 3, SEED = 123)

## ----ensemble results for Biase dataset, message=FALSE------------------------
cluster.ensemble

## ----ARI calculation for Biase dataset----------------------------------------
# Cell labels of ground truth
head(data_SAME$Biase.celltype)

# Calculating ARI for cluster ensemble
adjustedRandIndex(cluster.ensemble$AICcluster, data_SAME$Biase.celltype)

